<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>BookmarksWidget</name>
    <message>
        <location filename="../forms/bookmarkswidget.ui" line="32"/>
        <source>Filter:</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>FontDialog</name>
    <message>
        <location filename="../forms/fontdialog.ui" line="14"/>
        <location filename="../forms/fontdialog.ui" line="73"/>
        <source>Select Terminal Font</source>
        <translation>Velg terminalens skrift</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="32"/>
        <source>Font:</source>
        <translation>Skrift:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="42"/>
        <source>Size:</source>
        <translation>Størrelse:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="59"/>
        <source>Preview</source>
        <translation>Forhåndsvisning</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="92"/>
        <source>Bookmarks</source>
        <translation>Bokmerker</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="192"/>
        <source>Press &quot;%1&quot; to see the terminal.</source>
        <translation>Trykk på &quot;%1&quot; for å se terminalen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="241"/>
        <source>&amp;Next Tab</source>
        <translation>&amp;Neste fane</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="244"/>
        <source>&amp;Previous Tab</source>
        <translation>&amp;Forrige fane</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="253"/>
        <source>Move Tab &amp;Left</source>
        <translation>Flytt fane til &amp;venstre</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="256"/>
        <source>Move Tab &amp;Right</source>
        <translation>Flytt fane til &amp;høyre</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="275"/>
        <source>Split Terminal &amp;Horizontally</source>
        <translation>Del opp terminalen &amp;horisontalt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="278"/>
        <source>Split Terminal &amp;Vertically</source>
        <translation>Del opp terminalen &amp;vertikalt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="283"/>
        <source>&amp;Collapse Subterminal</source>
        <translation>&amp;Brett sammen underterminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="234"/>
        <source>&amp;Clear Active Terminal</source>
        <translation>&amp;Ta vekk alt fra aktiv terminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="247"/>
        <source>&amp;Previous Tab in History</source>
        <translation>&amp;Forrige fane i historikk</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="250"/>
        <source>&amp;Next Tab in History</source>
        <translation>&amp;Neste fane i historikk</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="261"/>
        <source>Tab</source>
        <translation>Tabulatur</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="262"/>
        <source>Go to</source>
        <translation>Gå til</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>&amp;Top Subterminal</source>
        <translation>&amp;Øverste underterminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="289"/>
        <source>&amp;Bottom Subterminal</source>
        <translation>&amp;Nederste underterminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="292"/>
        <source>L&amp;eft Subterminal</source>
        <translation>&amp;Venstre underterminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="295"/>
        <source>R&amp;ight Subterminal</source>
        <translation>&amp;Høyre underterminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>Copy &amp;Selection</source>
        <translation>Kopier &amp;markering</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="305"/>
        <source>Paste Clip&amp;board</source>
        <translation>Lim inn fra &amp;utklippsboken</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="308"/>
        <source>Paste S&amp;election</source>
        <translation>Lim inn m&amp;arkering</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="311"/>
        <source>Zoom &amp;in</source>
        <translation>Zoom &amp;inn</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="314"/>
        <source>Zoom &amp;out</source>
        <translation>Zoom &amp;ut</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="317"/>
        <source>Zoom rese&amp;t</source>
        <translation>&amp;Nullstill zoom</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="322"/>
        <source>&amp;Find...</source>
        <translation>&amp;Finn...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="325"/>
        <source>Handle history...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="333"/>
        <source>&amp;Save Session</source>
        <translation>&amp;Lagre sesjon</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="339"/>
        <source>&amp;Load Session</source>
        <translation>Last &amp;inn sesjon</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="346"/>
        <source>&amp;Toggle Menu</source>
        <translation>&amp;Skru meny av eller på</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="351"/>
        <source>Rename session</source>
        <translation>Gi nytt navn til sesjon</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <source>&amp;New Tab</source>
        <translation>&amp;Ny fane</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="364"/>
        <source>New Tab From &amp;Preset</source>
        <translation>Ny fane fra &amp;forhåndstinnstilling</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="365"/>
        <source>1 &amp;Terminal</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>2 &amp;Horizontal Terminals</source>
        <translation>2 &amp;Horisontale terminaler</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="369"/>
        <source>2 &amp;Vertical Terminals</source>
        <translation>2 &amp;Vertikale terminaler</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="371"/>
        <source>4 Terminal&amp;s</source>
        <translation>4 Terminal&amp;er</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="377"/>
        <source>&amp;Close Tab</source>
        <translation>&amp;Lukk fane</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="380"/>
        <source>&amp;New Window</source>
        <translation>&amp;Nytt vindu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="385"/>
        <source>&amp;Preferences...</source>
        <translation>&amp;Innstillinger...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="389"/>
        <source>&amp;Quit</source>
        <translation>&amp;Avslutt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="395"/>
        <source>&amp;Hide Window Borders</source>
        <translation>&amp;Skjul kanter rundt vinduer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="413"/>
        <source>&amp;Show Tab Bar</source>
        <translation>&amp;Vis fanelinjen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="421"/>
        <source>Fullscreen</source>
        <translation>Fullskjerm</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="427"/>
        <source>Toggle Bookmarks</source>
        <translation>Skru bokmerker av eller på</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="435"/>
        <source>&amp;Bottom</source>
        <translation>&amp;Nederst</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <source>&amp;Top</source>
        <translation>&amp;Øverst</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="437"/>
        <location filename="../mainwindow.cpp" line="473"/>
        <source>&amp;Right</source>
        <translation>&amp;Høyre</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="438"/>
        <location filename="../mainwindow.cpp" line="474"/>
        <source>&amp;Left</source>
        <translation>&amp;Venstre</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="456"/>
        <source>&amp;Tabs Layout</source>
        <translation>Layout for &amp;faner</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="472"/>
        <source>&amp;None</source>
        <translation>&amp;Ingen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="490"/>
        <source>S&amp;crollbar Layout</source>
        <translation>Layout for &amp;rullefelt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="503"/>
        <source>&amp;BlockCursor</source>
        <translation>&amp;Blokkmarkør</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="504"/>
        <source>&amp;UnderlineCursor</source>
        <translation>&amp;Understreksmarkør</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="505"/>
        <source>&amp;IBeamCursor</source>
        <translation>&amp;Strekmarkør</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="522"/>
        <source>&amp;Keyboard Cursor Shape</source>
        <translation>&amp;Tastaturmarkørens form</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="622"/>
        <source>Exit QTerminal</source>
        <translation>Avslutt QTerminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="624"/>
        <source>Do not ask again</source>
        <translation>Ikke spør igjen</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="632"/>
        <source>Are you sure you want to exit?</source>
        <translation>Vil du virkelig avslutte?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="663"/>
        <source>A lightweight multiplatform terminal emulator</source>
        <translation>En lettvekts multiplatform terminalemulator</translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="14"/>
        <source>Terminal settings</source>
        <translation>Terminalinnstillinger</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="31"/>
        <source>Appearance</source>
        <translation>Utseende</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="39"/>
        <location filename="../forms/propertiesdialog.ui" line="575"/>
        <source>Behavior</source>
        <translation>Oppførsel</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="47"/>
        <source>Shortcuts</source>
        <translation>Snareveier</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="55"/>
        <source>Dropdown</source>
        <translation>Rullegardinmeny</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="63"/>
        <source>Bookmarks</source>
        <translation>Bokmerker</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="258"/>
        <source>Hide tab bar with only one tab</source>
        <translation>Skjul fanelinjen når det bare er én fane</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="275"/>
        <source>Color scheme</source>
        <translation>Fargetema</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="335"/>
        <source>Scrollbar position</source>
        <translation>Plassering av rullefelt</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="204"/>
        <source>Start with preset:</source>
        <translation>Start med forhåndsinnstilling:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="368"/>
        <source>Show a border around the current terminal</source>
        <translation>Vis en kant rundt den aktive terminalen</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="345"/>
        <source>Terminal transparency</source>
        <translation>Terminalens gjennomsiktighet</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="358"/>
        <source>Application transparency</source>
        <translation>Programmets gjennomsiktighet</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="215"/>
        <source>None (single terminal)</source>
        <translation>Ingen (én terminal)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="220"/>
        <source>2 terminals horizontally</source>
        <translation>2 terminaler horisontalt</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="225"/>
        <source>2 terminals vertically</source>
        <translation>2 terminaler vertikalt</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="230"/>
        <source>4 terminals</source>
        <translation>4 terminaler</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="117"/>
        <location filename="../forms/propertiesdialog.ui" line="389"/>
        <source> %</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="148"/>
        <source>Font</source>
        <translation>Skrift</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="184"/>
        <source>&amp;Change...</source>
        <translation>&amp;Endre...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="418"/>
        <source>Tabs position</source>
        <translation>Plassering av faner</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="238"/>
        <source>Widget style</source>
        <translation>Widgetstil</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="194"/>
        <source>Show the menu bar</source>
        <translation>Vis menylinjen</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="299"/>
        <source>Cursor shape</source>
        <translation>Markørens form</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="428"/>
        <source>Change window title based on current terminal</source>
        <translation>Endre vinduets tittel basert på aktiv terminal</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="445"/>
        <source>Change window icon based on current terminal</source>
        <translation>Endre vinduets symbol basert på aktiv terminal</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="382"/>
        <source>Enable bi-directional text support</source>
        <translation>Aktiver støtte for tekst i begge retninger</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="265"/>
        <source>Background image:</source>
        <translation>Bakgrunnsbilde:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="290"/>
        <source>Select</source>
        <translation>Velg</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="452"/>
        <source>Show terminal size on resize</source>
        <translation>Vis terminalens størrelse når den endres</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="435"/>
        <source>Fixed tab width:</source>
        <translation>Fast bredde for faner:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="375"/>
        <location filename="../forms/propertiesdialog.ui" line="408"/>
        <source>px</source>
        <translation>pk</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="325"/>
        <source>Show close button on each tab</source>
        <translation>Vis lukkeknapp i hver fane</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="248"/>
        <source>Terminal margin</source>
        <translation>Terminalmarg</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="462"/>
        <source>Use box drawing characters contained in the font</source>
        <translation>Bruk tegn for å lage bokser fra den valgte skriften</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="469"/>
        <source>Accelerators are activated by Alt and can interfere with the terminal.</source>
        <translation>Akselleratorer blir aktivert med Alt og kan blande seg inn i det som skjer i terminalen.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="472"/>
        <source>No menu bar accelerator</source>
        <translation>Ingen menylinje aksellerasjon</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="550"/>
        <source>Emulation</source>
        <translation>Emulering</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="675"/>
        <source>Action after paste</source>
        <translation>Handling etter lim inn</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="712"/>
        <source>Confirm multiline paste</source>
        <translation>Bekreft lim inn med flere linjer</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="753"/>
        <source>Trim trailing newlines in pasted text</source>
        <translation>Fjern etterfølgende linjeskift i innlimt tekst</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="688"/>
        <source>Open new terminals in current working directory</source>
        <translation>Åpne nye terminaler i aktiv mappe</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="719"/>
        <source>Save Size when closing</source>
        <translation>Lagre størrelse ved lukking</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="760"/>
        <source>Save Position when closing</source>
        <translation>Lagre plassering ved lukking</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="736"/>
        <source>Ask for confirmation when closing</source>
        <translation>Spør om bekreftelse ved lukking</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="780"/>
        <source>Unlimited history</source>
        <translation>Ubegrenset historikk</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="746"/>
        <source>History size (in lines)</source>
        <translation>Størrelse på historikk (i linjer)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="705"/>
        <source>Default $TERM</source>
        <translation>Standard-$TERM</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="596"/>
        <source>Start with this size:</source>
        <translation>Start med denne størrelsen:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="459"/>
        <source>Specify whether box drawing characters should be drawn by QTerminal internally or left to underlying font rendering libraries.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="479"/>
        <source>Toggles usage of bold font face for rendering intense colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="482"/>
        <source>Use bold font face for intense colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="489"/>
        <source>&amp;Hide Window Borders</source>
        <translation type="unfinished">&amp;Skjul kanter rundt vinduer</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="559"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;If you are not sure, use the &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="581"/>
        <source>This command will be run with an argument containing the file name of a tempfile containing the scrollback history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="584"/>
        <source>Handle history command</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="603"/>
        <location filename="../forms/propertiesdialog.ui" line="617"/>
        <source> px</source>
        <translation> pk</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="624"/>
        <source>Get current size</source>
        <translation>Få nåværende størrelse</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="695"/>
        <source>Open new tab to the right of the active tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="698"/>
        <source>If unchecked the new tab will be opened as the rightmost tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="726"/>
        <source>Close tab on middle-click</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="798"/>
        <source>To edit a Shortcut:
1. Double-click its Key
2. Press the desired combination and release it
3. Click on a Shortcut or press Enter

To remove/disable a Shortcut, at point 2 press only a modifier (like Shift)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="828"/>
        <source>Shortcut</source>
        <translation>Tastatursnarevei</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="833"/>
        <source>Key</source>
        <translation>Tast</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="845"/>
        <source>Show on start</source>
        <translation>Vis ved start</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="852"/>
        <source>Size</source>
        <translation>Størrelse</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="863"/>
        <source>Height</source>
        <translation>Høyde</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="873"/>
        <location filename="../forms/propertiesdialog.ui" line="890"/>
        <source>%</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="880"/>
        <source>Width</source>
        <translation>Bredde</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="904"/>
        <source>Shortcut:</source>
        <translation>Tastatursnarevei:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="936"/>
        <source>Edit bookmark file contents</source>
        <translation>Rediger innholdet i bokmerkefilen</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="958"/>
        <source>Enable bookmarks</source>
        <translation>Aktiver bokmerker</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="967"/>
        <source>Bookmark file</source>
        <translation>Bokmerkefil</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="980"/>
        <source>Find...</source>
        <translation>Finn...</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="989"/>
        <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
        <translation>Du kan bestemme plasseringen for bokmerkefilen. Det gjør det lett å dele bokmerker med OwnCloud eller Dropbox.</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="145"/>
        <source>No scrollbar</source>
        <translation>Ikke noe rullefelt</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="145"/>
        <location filename="../propertiesdialog.cpp" line="151"/>
        <source>Left</source>
        <translation>Venstre</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="145"/>
        <location filename="../propertiesdialog.cpp" line="151"/>
        <source>Right</source>
        <translation>Høyre</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="151"/>
        <source>Top</source>
        <translation>Øverst</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="151"/>
        <source>Bottom</source>
        <translation>Nederst</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="164"/>
        <source>BlockCursor</source>
        <translation>Blokkmarkør</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="164"/>
        <source>UnderlineCursor</source>
        <translation>Understrekingsmarkør</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="164"/>
        <source>IBeamCursor</source>
        <translation>Strekmarkør</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="182"/>
        <source>No move</source>
        <translation>Ingen flytting</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="182"/>
        <source>Move start</source>
        <translation>Flytt begynnelse</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="182"/>
        <source>Move end</source>
        <translation>Flytt slutt</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="187"/>
        <location filename="../propertiesdialog.cpp" line="282"/>
        <source>System Default</source>
        <translation>Systemstandard</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="375"/>
        <source>Choose a background image</source>
        <translation>Velg et bakgrunnsbilde</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="376"/>
        <source>Images (*.bmp *.png *.xpm *.jpg)</source>
        <translation>Bilder (*.bmp *.png *.xpm *.jpg)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="439"/>
        <source>Open or create bookmarks file</source>
        <translation>Åpne eller lag en bokmerkefil</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <location filename="../termwidget.cpp" line="239"/>
        <source>Show Details...</source>
        <translation>Vis detaljer...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../bookmarkswidget.cpp" line="108"/>
        <source>Local Bookmarks</source>
        <translation>Lokale bokmerker</translation>
    </message>
    <message>
        <location filename="../bookmarkswidget.cpp" line="166"/>
        <source>Synchronized Bookmarks</source>
        <translation>Synkroniserte bokmerker</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <location filename="../tabwidget.cpp" line="78"/>
        <location filename="../tabwidget.cpp" line="232"/>
        <source>Shell No. %1</source>
        <translation>Skall nr. %1</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="200"/>
        <source>Tab name</source>
        <translation>Fanenavn</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="201"/>
        <source>New tab name:</source>
        <translation>Nytt fanenavn:</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="221"/>
        <source>Select new tab title color</source>
        <translation>Velg ny farge til fanetittelen</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="242"/>
        <source>Close session</source>
        <translation>Lukk sesjon</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="244"/>
        <source>Change title color</source>
        <translation>Skift farge på tittelen</translation>
    </message>
</context>
<context>
    <name>TermWidgetHolder</name>
    <message>
        <location filename="../termwidgetholder.cpp" line="79"/>
        <source>Load Session</source>
        <translation>Last inn sesjon</translation>
    </message>
    <message>
        <location filename="../termwidgetholder.cpp" line="80"/>
        <source>List of saved sessions:</source>
        <translation>Liste over lagrede sesjoner:</translation>
    </message>
</context>
<context>
    <name>TermWidgetImpl</name>
    <message>
        <location filename="../termwidget.cpp" line="231"/>
        <source>Paste multiline text</source>
        <translation>Lim inn flerlinjet tekst</translation>
    </message>
    <message>
        <location filename="../termwidget.cpp" line="232"/>
        <source>Are you sure you want to paste this text?</source>
        <translation>Er du sikker på at du vil lime inn denne teksten?</translation>
    </message>
</context>
<context>
    <name>mainWindow</name>
    <message>
        <location filename="../forms/qterminal.ui" line="14"/>
        <source>MainWindow</source>
        <translation>HovedVindu</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="59"/>
        <source>&amp;File</source>
        <translation>&amp;Fil</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="67"/>
        <source>&amp;Actions</source>
        <translation>&amp;Handlinger</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="72"/>
        <source>&amp;Help</source>
        <translation>&amp;Hjelp</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="79"/>
        <source>&amp;View</source>
        <translation>&amp;Vis</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="84"/>
        <source>&amp;Edit</source>
        <translation>&amp;Rediger</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="100"/>
        <source>&amp;About...</source>
        <translation>&amp;Om...</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="105"/>
        <source>About &amp;Qt...</source>
        <translation>Om &amp;Qt...</translation>
    </message>
</context>
</TS>
